@@ -7,11 +7,11 @@ package Template::Mustache;
 use strict;
 use warnings;
 
-use CGI ();
+use HTML::Entities;
 use File::Spec;
 use Scalar::Util 'blessed';
 
-use version 0.77; our $VERSION = qv("v0.5.2");
+use version 0.77; our $VERSION = qv("v0.5.3");
 
 my %TemplateCache;
 
@@ -219,7 +219,7 @@ sub generate {
                     $ctx->{$tag} = $value if ref $ctx eq 'HASH';
                 }
                 # An empty `$type` represents an HTML escaped tag.
-                $value = CGI::escapeHTML($value) unless $type;
+                $value = encode_entities($value) unless $type;
                 @result = $value;
             } elsif ($type eq '#') {
                 # Section Tags
